#[repr(i32)]pub enum ComponentType {
Unspecified = 0,
Bytes = 1,
String = 2,
TlsMapBytesBytes = 3,
TlsMapInboxIdBytes = 4,
TlsSetBytes = 5,
TlsSetInboxId = 6,
}Expand description
The data structure type of a component’s value
Variants
Unspecified = 0
Bytes = 1
Opaque bytes, replaced atomically
String = 2
A utf-8 encoded string, replaced atomically
TlsMapBytesBytes = 3
A TlsMap<bytes, bytes> supporting key-level insert/update/delete via deltas
TlsMapInboxIdBytes = 4
A TlsMap<InboxId, bytes> supporting key-level insert/update/delete via deltas
TlsSetBytes = 5
A TlsSet
TlsSetInboxId = 6
A TlsSet
Implementations
Sourceimpl ComponentType
impl ComponentType
Sourceimpl ComponentType
impl ComponentType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.