#[repr(i32)]pub enum WelcomePointerWrapperAlgorithm {
Unspecified = 0,
XwingMlkem768Draft6 = 2,
}Expand description
MUST match the WelcomeWrapperAlgorithm enum values without 25519 so that the i32 transformations are compatible
Variants
Implementations
Sourceimpl WelcomePointerWrapperAlgorithm
impl WelcomePointerWrapperAlgorithm
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of WelcomePointerWrapperAlgorithm.
Sourcepub fn from_i32(value: i32) -> Option<WelcomePointerWrapperAlgorithm>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<WelcomePointerWrapperAlgorithm>
Use the TryFrom<i32> implementation instead
Converts an i32 to a WelcomePointerWrapperAlgorithm, or None if value is not a valid variant.
Sourceimpl WelcomePointerWrapperAlgorithm
impl WelcomePointerWrapperAlgorithm
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.