#[repr(i32)]pub enum WelcomeWrapperAlgorithm {
Unspecified = 0,
Curve25519 = 1,
XwingMlkem768Draft6 = 2,
SymmetricKey = 3,
}Expand description
Describes the algorithm used to encrypt the Welcome Wrapper
Variants
Unspecified = 0
Curve25519 = 1
XwingMlkem768Draft6 = 2
SymmetricKey = 3
Only used for WelcomePointee’s
Implementations
Sourceimpl WelcomeWrapperAlgorithm
impl WelcomeWrapperAlgorithm
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of WelcomeWrapperAlgorithm.
Sourcepub fn from_i32(value: i32) -> Option<WelcomeWrapperAlgorithm>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<WelcomeWrapperAlgorithm>
Use the TryFrom<i32> implementation instead
Converts an i32 to a WelcomeWrapperAlgorithm, or None if value is not a valid variant.
Sourceimpl WelcomeWrapperAlgorithm
impl WelcomeWrapperAlgorithm
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.