pub struct PlaintextCommitLogEntry {
pub group_id: Vec<u8>,
pub commit_sequence_id: u64,
pub last_epoch_authenticator: Vec<u8>,
pub commit_result: i32,
pub applied_epoch_number: u64,
pub applied_epoch_authenticator: Vec<u8>,
}Expand description
PlaintextCommitLogEntry indicates whether a commit was successful or not,
when applied on top of the indicated last_epoch_authenticator.
Fields
group_id: Vec<u8>The group_id of the group that the commit belongs to.
commit_sequence_id: u64The sequence ID of the commit payload being validated.
last_epoch_authenticator: Vec<u8>The encryption state before the commit was applied.
commit_result: i32Indicates whether the commit was successful, or why it failed.
applied_epoch_number: u64The epoch number after the commit was applied, if successful.
applied_epoch_authenticator: Vec<u8>The encryption state after the commit was applied, if successful.
Implementations
Sourceimpl PlaintextCommitLogEntry
impl PlaintextCommitLogEntry
Sourcepub fn commit_result(&self) -> CommitResult
pub fn commit_result(&self) -> CommitResult
Returns the enum value of commit_result, or the default if the field is set to an invalid enum value.
Sourcepub fn set_commit_result(&mut self, value: CommitResult)
pub fn set_commit_result(&mut self, value: CommitResult)
Sets commit_result to the provided enum value.