pub struct WelcomeWrapperEncryption {
pub pub_key: Vec<u8>,
pub algorithm: i32,
}Expand description
The KeyPackageExtension that stores the PubKey and the WelcomeWrapperEncryption
Fields
pub_key: Vec<u8>algorithm: i32Implementations
Sourceimpl WelcomeWrapperEncryption
impl WelcomeWrapperEncryption
Sourcepub fn algorithm(&self) -> WelcomeWrapperAlgorithm
pub fn algorithm(&self) -> WelcomeWrapperAlgorithm
Returns the enum value of algorithm, or the default if the field is set to an invalid enum value.
Sourcepub fn set_algorithm(&mut self, value: WelcomeWrapperAlgorithm)
pub fn set_algorithm(&mut self, value: WelcomeWrapperAlgorithm)
Sets algorithm to the provided enum value.